common

package
v0.0.16 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 1, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type SizeAsymetrycKey

type SizeAsymetrycKey uint

SizeAsymetrycKey defines the supported asymmetric key sizes in bits.

const (
	// Key2048Bits represents a 2048-bit asymmetric key.
	Key2048Bits SizeAsymetrycKey = 2048
	// Key3072Bits represents a 3072-bit asymmetric key.
	Key3072Bits SizeAsymetrycKey = 3072
	// Key4096Bits represents a 4096-bit asymmetric key.
	Key4096Bits SizeAsymetrycKey = 4096
)

type SizeSymetrycKey

type SizeSymetrycKey uint

SizeSymetrycKey defines the supported symmetric key sizes in bytes.

const (
	// Key128Bits represents a 128-bit symmetric key.
	Key128Bits SizeSymetrycKey = 16
	// Key256Bits represents a 256-bit symmetric key.
	Key256Bits SizeSymetrycKey = 32
)

Jump to